@@ -4,21 +4,25 @@
 
   \author Satofumi KAMIMURA
 
-  $Id$
+  $Id: PartsConfig.cpp 263 2009-01-30 14:48:10Z satofumi $
 */
 
-#include <QColor>
 #include "PartsConfig.h"
+#include <QColor>
+#include <cstdlib>
+
+using namespace std;
 
 
 PartsConfig::PartsConfig(void)
   : type(""), font_size(14),
-    fore_color("ffffff"), back_color("777777"), offset(0) {
+    fore_color("ffffff"), back_color("777777"), offset(0)
+{
 }
 
 
-QColor PartsConfig::encodeColor(const std::string& color_str) {
-
+QColor PartsConfig::encodeColor(const string& color_str)
+{
   if (color_str.size() != 6) {
     return QColor(Qt::white);
   }
@@ -31,8 +35,8 @@ QColor PartsConfig::encodeColor(const std::string& color_str) {
 }
 
 
-const std::string PartsConfig::decodeColor(int r, int g, int b) {
-
+const string PartsConfig::decodeColor(int r, int g, int b)
+{
   QString color_str;
   color_str.sprintf("%02x%02x%02x", r, g, b);
   return color_str.toStdString();
@@ -40,8 +44,8 @@ const std::string PartsConfig::decodeColor(int r, int g, int b) {
 
 
 // フォントスタイルの取得
-QFont::Style PartsConfig::fontStyle(const std::string& style_name) {
-
+QFont::Style PartsConfig::fontStyle(const string& style_name)
+{
   QString style_string = QString(style_name.c_str());
 
   if (style_string.contains("Italic")) {
@@ -57,8 +61,8 @@ QFont::Style PartsConfig::fontStyle(const std::string& style_name) {
 
 
 // フォント属性の取得
-QFont::Weight PartsConfig::fontWeight(const std::string& weight_name) {
-
+QFont::Weight PartsConfig::fontWeight(const string& weight_name)
+{
   QString weight_string = QString(weight_name.c_str());
 
   if (weight_string.contains("Bold")) {
