@@ -4,24 +4,26 @@
 
   \author Satofumi KAMIMURA
 
-  $Id$
+  $Id: parts_generator.cpp 263 2009-01-30 14:48:10Z satofumi $
 */
 
+#include "PartsGeneratorWindow.h"
 #include <QApplication>
 #include <QTranslator>
-#include "PartsGeneratorWindow.h"
 
 
-namespace {
-  typedef struct {
+namespace
+{
+  typedef struct
+  {
     QString config_file;
   } options_t;
-};
+}
 
 
 // オプション処理
-static options_t optionHandler(int argc, char *argv[]) {
-
+static options_t optionHandler(int argc, char *argv[])
+{
   options_t options;
 
   for (int i = 1; i < argc; ++i) {
@@ -33,8 +35,8 @@ static options_t optionHandler(int argc, char *argv[]) {
 
 
 //! メイン
-int main(int argc, char *argv[]) {
-
+int main(int argc, char *argv[])
+{
   QApplication app(argc, argv);
 
   // ロケールの適用
