@@ -7,10 +7,11 @@
 
   \author Satofumi KAMIMURA
 
-  $Id$
+  $Id: AnimationManager.h 276 2009-10-22 03:44:32Z satofumi $
 */
 
 #include <QObject>
+#include <memory>
 #include <vector>
 
 class AnimationPattern;
@@ -19,26 +20,18 @@ class AnimationPattern;
 /*!
   \brief アニメーション管理クラス
 */
-class AnimationManager : public QObject {
+class AnimationManager : public QObject
+{
   Q_OBJECT;
 
-  AnimationManager(const AnimationManager& rhs);
-  AnimationManager& operator = (const AnimationManager& rhs);
-
-  struct pImpl;
-  std::auto_ptr<pImpl> pimpl;
-
-private slots:
-  void updateAnimation(void);
-
 public:
 
   /*!
     \brief コンストラクタ
 
-    \param cycle_msec [i] 制御周期 [msec]
-    \param patterns [i] アニメーション再生パターン
-    \param parent [i] 親オブジェクト
+    \param[in] cycle_msec 制御周期 [msec]
+    \param[in] patterns アニメーション再生パターン
+    \param[in] parent 親オブジェクト
   */
   AnimationManager(size_t cycle_msec,
                    const std::vector<AnimationPattern>& patterns,
@@ -55,9 +48,19 @@ signals:
   /*!
     \brief セルの更新
 
-    \param cell_index [i] 描画するセル
+    \param[in] cell_index 描画するセル
   */
   void updateCell(int cell_index);
+
+private slots:
+  void updateAnimation(void);
+
+private:
+  AnimationManager(const AnimationManager& rhs);
+  AnimationManager& operator = (const AnimationManager& rhs);
+
+  struct pImpl;
+  std::auto_ptr<pImpl> pimpl;
 };
 
 #endif /* !ANIMATION_MANATGER_H */
