@@ -7,7 +7,7 @@
 
   \author Satofumi KAMIMURA
 
-  $Id$
+  $Id: AnimationPattern.h 261 2009-01-22 06:48:10Z satofumi $
 */
 
 #include <vector>
@@ -17,8 +17,8 @@
 /*!
   \brief セル用タグ
 */
-class AnimationCellTag {
-
+class AnimationCellTag
+{
   AnimationCellTag(void);
 
 public:
@@ -30,7 +30,7 @@ public:
   /*!
     \brief コンストラクタ
 
-    \param index [i] ID 番号
+    \param[in] index ID 番号
   */
   AnimationCellTag(size_t index);
 };
@@ -39,8 +39,8 @@ public:
 /*!
   \brief パターン用タグ
 */
-class AnimationPatternTag {
-
+class AnimationPatternTag
+{
   AnimationPatternTag(void);
 
 public:
@@ -52,7 +52,7 @@ public:
   /*!
     \brief コンストラクタ
 
-    \param index [i] ID 番号
+    \param[in] index ID 番号
   */
   AnimationPatternTag(size_t index);
 };
@@ -61,7 +61,8 @@ public:
 /*!
   \brief アニメーションの再生パターン管理
 */
-class AnimationPattern {
+class AnimationPattern
+{
 public:
   double probability;           //!< 発生確率 / 秒 [1]
   size_t cycle_msec;            //!< 描画周期 [msec]
