@@ -4,24 +4,29 @@
 
   \author Satofumi KAMIMURA
 
-  $Id$
+  $Id: ClockPartsDraw.cpp 283 2011-07-03 19:09:08Z satofumi $
 */
 
+#include "ThemeResource.h"
+#include "ThemeClockDraw.h"
+#include "AnimationPattern.h"
 #include <QPainter>
 #include <QBitmap>
 #include <QTime>
 #include <cmath>
-#include "ThemeResource.h"
-#include "ThemeClockDraw.h"
-#include "AnimationPattern.h"
+#include <cstdio>
+
+using namespace std;
 
 
-namespace {
+namespace
+{
   static const bool CenterPosition = true; // 画像中心を基準にした描画を指示
 
   static int last_cell_index_ = ClockPartsDraw::NoAnimationCell;
 
-  class SecondPixmap {
+  class SecondPixmap
+  {
   public:
     qint64 cache_key_;
     size_t scaling_percent_;
@@ -29,13 +34,15 @@ namespace {
     size_t size_width_;
     size_t size_height_;
 
-    SecondPixmap(void) : cache_key_(0), scaling_percent_(0) {
+    SecondPixmap(void) : cache_key_(0), scaling_percent_(0)
+    {
     }
   };
 
 
   // 画面に描画するよりもコピーの方が時間コストが安いため、コピーで対処する
-  class DrawPartsData {
+  class DrawPartsData
+  {
   public:
     QPixmap pixmap_;
     QRect draw_rect_;
@@ -43,16 +50,18 @@ namespace {
 
     DrawPartsData(const QPixmap& pixmap,
                   const QRect& draw_rect, const QRect& source_rect)
-      : pixmap_(pixmap), draw_rect_(draw_rect), source_rect_(source_rect) {
+      : pixmap_(pixmap), draw_rect_(draw_rect), source_rect_(source_rect)
+    {
     }
   };
-  static std::vector<DrawPartsData> draw_parts_;
+  static vector<DrawPartsData> draw_parts_;
   static bool is_drawn_ = false;
 
 
   // 位置の取得
   QRect getPosition(const ThemeResource& resource,
-                    const std::string& tag_name) {
+                    const string& tag_name)
+  {
 
     return resource.offset.value(tag_name, QRect(0, 0, 0, 0));
   }
@@ -61,16 +70,16 @@ namespace {
   // 画像の描画
   void drawPixmap(QRegion& region,
                   const ThemeResource& resource,
-                  const std::string& tag_name,
+                  const string& tag_name,
                   const QRect& offset,
                   size_t scaling_percent,
                   qreal rotate_degree = 0.0,
                   bool center_position = false,
-                  bool erase_bottom_line = false) {
-
+                  bool erase_bottom_line = false)
+  {
     // ローカルのキャッシュサイズを確保
     static QPixmap no_second_pixmap;
-    static std::vector<SecondPixmap> second_pixmaps;
+    static vector<SecondPixmap> second_pixmaps;
     if (second_pixmaps.empty()) {
       second_pixmaps.resize(60);
     }
@@ -165,8 +174,8 @@ namespace {
 
   // アナログ部分の再描画
   void updateAnalog(QRegion& region, const ThemeResource& resource,
-                    int hour, int minute, int second, size_t scaling_percent) {
-
+                    int hour, int minute, int second, size_t scaling_percent)
+  {
     // 針の角度を再計算
     qreal analog_h_degree = (360.0 * (hour / 12.0)) + (30.0 * (minute / 60.0));
     QRect analog_h_offset = getPosition(resource, "analog/hari_h");
@@ -192,8 +201,8 @@ namespace {
   void updateDigital(QRegion& region,
                      const ThemeResource& resource,
                      const QVector<QPoint>& digital_positions,
-                     int hour, int minute, int second, size_t scaling_percent) {
-
+                     int hour, int minute, int second, size_t scaling_percent)
+  {
     enum { BufferSize = 11 };
     char buffer[BufferSize] = "hh:mm ss x";
 
@@ -246,19 +255,31 @@ namespace {
   void updateCalendar(QRegion& region, const ThemeResource& resource,
                       const QVector<QPoint>& calendar_positions,
                       int month, int day, int day_of_week,
-                      size_t scaling_percent) {
-
+                      size_t scaling_percent)
+  {
     enum { BufferSize = 5 };
     char buffer[BufferSize] = "mmdd";
 
     bool calendar_month =
       ! resource.option.value("calendar/month", "").compare("on");
+    bool zero_digit =
+      ! resource.option.value("calendar/zero", "").compare("on");
     if (calendar_month) {
       // 月を描画する
-      snprintf(buffer, BufferSize, "%02d%02d", month, day);
+      if (! zero_digit) {
+        // 10 の位がゼロのときに表示しない
+        snprintf(buffer, BufferSize, "%2d%2d", month, day);
+      } else {
+        snprintf(buffer, BufferSize, "%02d%02d", month, day);
+      }
     } else {
       // 月は描画しない
-      snprintf(buffer, BufferSize, "__%02d", day);
+      if (! zero_digit) {
+        // 10 の位がゼロのときに表示しない
+        snprintf(buffer, BufferSize, "__%2d", day);
+      } else {
+        snprintf(buffer, BufferSize, "__%02d", day);
+      }
     }
 
     // セパレータの描画
@@ -321,8 +342,8 @@ namespace {
 
   // 追加部品の描画
   void updateAdditional(QRegion& region, const ThemeResource& resource,
-                        size_t scaling_percent) {
-
+                        size_t scaling_percent)
+  {
     QRect additional_offset = getPosition(resource, "additional/near");
     drawPixmap(region, resource, "additional/near",
                additional_offset, scaling_percent);
@@ -331,8 +352,8 @@ namespace {
 
   // アニメーションセルの描画
   void updateAnimationCell(QRegion& region, const ThemeResource& resource,
-                           size_t cell_index, size_t scaling_percent) {
-
+                           size_t cell_index, size_t scaling_percent)
+  {
     if (last_cell_index_ == ClockPartsDraw::NoAnimationCell) {
       return;
     }
@@ -342,7 +363,7 @@ namespace {
     drawPixmap(region, resource, cell_tags.cell_tag,
                cell_offset, scaling_percent, 0.0, false, true);
   }
-};
+}
 
 
 // 再描画
@@ -351,8 +372,8 @@ void ClockPartsDraw::updatePixmaps(QRegion& region,
                                    const QVector<QPoint>& digital_positions,
                                    const QVector<QPoint>& calendar_positions,
                                    size_t scaling_percent, int sec_offset,
-                                   int cell_index) {
-
+                                   int cell_index)
+{
   // 描画部品をクリア
   draw_parts_.clear();
 
@@ -402,8 +423,8 @@ void ClockPartsDraw::updatePixmaps(QRegion& region,
 
 
 // 画像部品の描画
-void ClockPartsDraw::drawPixmaps(QPainter& painter, bool force_draw) {
-
+void ClockPartsDraw::drawPixmaps(QPainter& painter, bool force_draw)
+{
   if (! force_draw) {
     if (draw_parts_.empty() || is_drawn_) {
       // 描画すべき部品が何もなければ、戻る
@@ -414,7 +435,7 @@ void ClockPartsDraw::drawPixmaps(QPainter& painter, bool force_draw) {
   painter.setRenderHint(QPainter::SmoothPixmapTransform);
 
   // 実際の部品描画
-  for (std::vector<DrawPartsData>::iterator it = draw_parts_.begin();
+  for (vector<DrawPartsData>::iterator it = draw_parts_.begin();
        it != draw_parts_.end(); ++it) {
 
     QPixmap& pixmap = it->pixmap_;
