@@ -6,21 +6,26 @@
 
   \author Satofumi KAMIMURA
 
-  $Id$
+  $Id: RrdaResource.cpp 263 2009-01-30 14:48:10Z satofumi $
 */
 
+#include "RrdaResource.h"
 #include <fstream>
 #include <zlib.h>
 #include <vector>
-#include "RrdaResource.h"
+#include <cstring>
+
+using namespace std;
 
 
-namespace {
-  typedef std::vector<unsigned char> Buffer;
-};
+namespace
+{
+  typedef vector<unsigned char> Buffer;
+}
 
 
-struct RrdaResource::pImpl {
+struct RrdaResource::pImpl
+{
   enum {
     Reserved = 0xe0,
     ExtraField = 0x04,
@@ -39,9 +44,9 @@ struct RrdaResource::pImpl {
   size_t size_;
 
 
-  pImpl(std::ifstream& fin, size_t size)
-    : raw_memory_(NULL), raw_memory_size_(size), size_(0) {
-
+  pImpl(ifstream& fin, size_t size)
+    : raw_memory_(NULL), raw_memory_size_(size), size_(0)
+  {
     if (raw_memory_size_ > 0) {
       raw_memory_ = new unsigned char[raw_memory_size_];
     }
@@ -51,13 +56,15 @@ struct RrdaResource::pImpl {
   }
 
 
-  ~pImpl(void) {
+  ~pImpl(void)
+  {
     releaseTemporaryMemory();
   }
 
 
   // 一時リソースの解放
-  void releaseTemporaryMemory(void) {
+  void releaseTemporaryMemory(void)
+  {
     if (raw_memory_) {
       delete [] raw_memory_;
       raw_memory_ = NULL;
@@ -67,7 +74,8 @@ struct RrdaResource::pImpl {
 
 
   // リソースの取得
-  unsigned char* get(size_t* size) {
+  unsigned char* get(size_t* size)
+  {
     if (extended_memory_.empty()) {
       decompress(raw_memory_, raw_memory_size_);
     }
@@ -80,8 +88,8 @@ struct RrdaResource::pImpl {
 
 
   // リソースの解凍
-  bool decompress(const unsigned char* data_first, size_t area_size) {
-
+  bool decompress(const unsigned char* data_first, size_t area_size)
+  {
     const unsigned char* work = gz_header_check(data_first, area_size);
     if (work == NULL) {
       // zip ヘッダがない場合
@@ -99,7 +107,8 @@ struct RrdaResource::pImpl {
 
   // gz データのヘッダーチェックとスキップ
   // zlib の gzio.c 内ローカル関数 check_header() を参考にリライトしたもの
-  const unsigned char* gz_header_check(const unsigned char* data, size_t size) {
+  const unsigned char* gz_header_check(const unsigned char* data, size_t size)
+  {
     if (! data) {
       return NULL;
     }
@@ -169,8 +178,8 @@ struct RrdaResource::pImpl {
 
   // メモリ上の gz データを解凍し、ポインタを返す
   // ヘッダーは既にスキップされて圧縮データ本体へのポインタが渡されているとする
-  bool gunzip_data(const unsigned char* data, long size) {
-
+  bool gunzip_data(const unsigned char* data, long size)
+  {
     // メモリ管理の指定
     z_stream z;
     z.zalloc = Z_NULL;
@@ -237,22 +246,25 @@ struct RrdaResource::pImpl {
 
     size_ = total_size;
     output_buffer.resize(total_size);
-    std::swap(output_buffer, extended_memory_);
+    swap(output_buffer, extended_memory_);
     return true;
   }
 };
 
 
-RrdaResource::RrdaResource(std::ifstream& fin, size_t size)
-  : pimpl(new pImpl(fin, size)) {
+RrdaResource::RrdaResource(ifstream& fin, size_t size)
+  : pimpl(new pImpl(fin, size))
+{
 }
 
 
-RrdaResource::~RrdaResource(void) {
+RrdaResource::~RrdaResource(void)
+{
 }
 
 
 // リソースを返す
-unsigned char* RrdaResource::get(size_t* size) {
+unsigned char* RrdaResource::get(size_t* size)
+{
   return pimpl->get(size);
 }
