@@ -4,7 +4,7 @@
 
   \author Satofumi KAMIMURA
 
-  $Id: ThemeClockWidget.cpp 289 2012-06-15 13:19:09Z satofumi $
+  $Id: ThemeClockWidget.cpp 294 2012-06-30 01:39:19Z satofumi $
 
   \todo 指定した拡張子のファイルのみ、ドラッグ可能にする
 */
@@ -217,15 +217,16 @@ ThemeClockWidget::ThemeClockWidget(const QString& theme_file,
                                    QWidget* parent)
   : QWidget(parent), pimpl(new pImpl(this))
 {
+  setWindowFlags(Qt::FramelessWindowHint);
+
   // 前回動作時の設定を読み出す
   pimpl->readSettings(position_specified, this);
 
   // テーマの読み出し
-  if (pimpl->tryLoadTheme(theme_file, this)) {
+  pimpl->tryLoadTheme(theme_file, this);
 #if defined(Q_OS_WIN32)
-    SetWindowLong(winId(), GWL_EXSTYLE, WS_EX_TOOLWINDOW);
+  SetWindowLong(winId(), GWL_EXSTYLE, WS_EX_TOOLWINDOW);
 #endif
-  }
   resize(pimpl->draw_widget_->size());
 
   // フォームの初期化
@@ -279,6 +280,8 @@ void ThemeClockWidget::mouseMoveEvent(QMouseEvent* event)
     move(event->globalPos() - pimpl->drag_position_);
     event->accept();
   }
+
+  pimpl->writeSettings(this);
 }
 
 
@@ -343,6 +346,8 @@ void ThemeClockWidget::changeScaling(int percent)
 
   pimpl->draw_widget_->updateScalingPercent(percent);
   resize(pimpl->draw_widget_->size());
+
+  pimpl->writeSettings(this);
 }
 
 
@@ -350,6 +355,8 @@ void ThemeClockWidget::changeNoAnimation(bool checked)
 {
   pimpl->no_animation_ = checked;
   pimpl->draw_widget_->setAnimationOn(pimpl->no_animation_);
+
+  pimpl->writeSettings(this);
 }
 
 
@@ -357,13 +364,18 @@ void ThemeClockWidget::placeTopHandler(bool checked)
 {
   pimpl->is_place_top_checked_ = checked;
 
-#if defined(Q_OS_WIN32)
   if (checked) {
-    SetWindowPos(this->winId(), HWND_TOPMOST, 0, 0, 0, 0,
-                 SWP_NOMOVE | SWP_NOSIZE | SWP_NOACTIVATE);
+    setWindowFlags(Qt::FramelessWindowHint |
+                   Qt::WindowStaysOnTopHint | Qt::X11BypassWindowManagerHint);
   } else {
-    SetWindowPos(this->winId(), HWND_NOTOPMOST, 0, 0, 0, 0,
-                 SWP_NOMOVE | SWP_NOSIZE | SWP_NOACTIVATE);
+    setWindowFlags(Qt::FramelessWindowHint);
   }
+#if defined(Q_OS_WIN32)
+  SetWindowLong(winId(), GWL_EXSTYLE, WS_EX_TOOLWINDOW);
 #endif
+
+  hide();
+  show();
+
+  pimpl->writeSettings(this);
 }
