@@ -7,17 +7,18 @@
 
   \author Satofumi KAMIMURA
 
-  $Id$
+  $Id: RrdaDecoder.h 264 2009-01-30 15:03:27Z satofumi $
 */
 
+#include <string>
 #include <memory>
 
 
 /*!
   \brief RRDA リソースのデコード
 */
-class RrdaDecoder {
-
+class RrdaDecoder
+{
   RrdaDecoder(void);
   RrdaDecoder(const RrdaDecoder& rhs);
   RrdaDecoder& operator = (const RrdaDecoder& rhs);
@@ -30,8 +31,8 @@ public:
   /*!
     \brief コンストラクタ
 
-    \param fileName [i] リソースファイル
-    \param key [i] キー
+    \param[in] fileName リソースファイル
+    \param[in] key キー
   */
   explicit RrdaDecoder(const std::string& fileName, const std::string& key);
   ~RrdaDecoder(void);
@@ -40,8 +41,8 @@ public:
   /*!
     \brief リリースデータの登録
 
-    \param tag [i] タグ
-    \param file [i] データファイル名
+    \param[in] tag タグ
+    \param[in] file データファイル名
   */
   void setNormalData(const std::string& tag, const std::string& file);
 
@@ -49,8 +50,8 @@ public:
   /*!
     \brief リリースデータの登録 (制限データ)
 
-    \param tag [i] タグ
-    \param file [i] データファイル名
+    \param[in] tag タグ
+    \param[in] file データファイル名
   */
   void setRestrictData(const std::string& tag, const std::string& file);
 
